import json
def read_json(file_path):
    with open(file_path, 'r') as json_file:
        data = json.load(json_file)
    return data

states = read_json('json/state.json')
country_data = read_json('json/countries.json')

def validate_state(state_name=None):
    if state_name is not None:
        for state in states:
            if state["name"] == state_name:
                data = state_name
                return data
        data = {'state': None}
        return data
    else:
        return 'Please Provide Valid Input'
    
# print(validate_state("Sind"))


def list_states(country_name= None):
    response_data = []
    if country_name is not None:
        for country in country_data:
            if country["name"] == country_name:
                data = country
                id = data['id']
                for state in states:
                    if state["country"] == str(id):
                        response_data.append(state)
                return response_data
        data = {'country': 'Invalid Country'}
        return data
    else:
        return 'Please Provide Valid Input'
    
# print(list_states("Pakistan"))
    


import json
def read_json(file_path):
    with open(file_path, 'r') as json_file:
        data = json.load(json_file)
    return data

states = read_json('json/state.json')
country_data = read_json('json/countries.json')
cities_data = read_json('json/cities.json')

# from country to cities
def list_cities(country_name= None):
    response_data = []
    state_data = []

    if country_name is not None:
        for country in country_data:
            if country["name"] == country_name:
                data = country
                id = data['id']
                for state in states:
                    if state["country"] == str(id):
                        state_id = state['id']
                        for city in cities_data:
                            if city['state'] == str(state_id):
                                state_data.append(city)
                        response = {
                            'state': state['name'],
                            'sate_id': state['id'],
                            'cities': state_data
                        }
                        state_data = []
                        response_data.append(response)
                # with open('output.json', 'w') as json_file:
                #     json.dump(response_data, json_file, indent=2)
                return response_data
        data = {'country': 'Invalid Country'}
        return data
    else:
        return 'Please Provide Valid Input'

# print(list_cities("Pakistan"))


# from state to cities
def list_state_cities(state_name= None):
    response_data = []
    state_data = []

    if state_name is not None:
        for state in states:
            if state['name'] == state_name:
                for city in cities_data:
                    if city['state'] == str(state['id']):
                        state_data.append(city)
                response = {
                    'state': state['name'],
                    'sate_id': state['id'],
                    'cities': state_data
                }
                return response

# print(list_state_cities("Punjab"))


from setuptools import setup, find_packages

with open('citier/README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='citier',
    version='1.3.6',
    packages=find_packages(),
    install_requires=[],
    entry_points={},
    description='An extensive Python Library to View, List and Validate Countries, States, and Cities data',
    long_description=long_description,
    long_description_content_type='text/markdown',
    
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)



import json
def read_json(file_path):
    with open(file_path, 'r') as json_file:
        data = json.load(json_file)
    return data

states = read_json('json/state.json')
country_data = read_json('json/countries.json')

def validate_country(country_name=None):
    if country_name is not None:
        for country in country_data:
            if country["name"] == country_name:
                data = country
                return data
        data = {'country': None}
        return data
    else:
        return 'Please Provide Valid Input'


# print(validate_country())

def countries_list(limit_start=None, limit_end=None):
    data = []
    if limit_start is not None and limit_end is not None:
        if limit_start <= limit_end:
            for country in country_data:
                if country['id'] >= limit_start and country['id'] <= limit_end:
                    data.append(country) 
            return data
        else:
            return 'Invalid Limit'
    else:
        for country in country_data:
            data.append(country) 
        return data
        
# print(countries_list(1,2))
# print(countries_list(2,1))
# print(countries_list())